# OCR-D Browser

An extensible viewer for [OCR-D](https://ocr-d.de/) mets.xml files 

## Screenshot

![OCRD Browser with two image and one xml view](docs/screenshot.png)

## Installation on Ubuntu 18.04

```
sudo apt install libcairo2-dev libgtk-3-dev libglib2.0-dev libgtksourceview-3.0-dev libgirepository1.0-dev pkg-config cmake
pip install browse-ocrd
```

## Usage
```
browse-ocrd ./path/to/mets.xml
```
